//----------------------------------------------------------------------
// File:			ALTSnumeric.h
// Programmer:		David Mount
// Description:		Definitions for numerical utilities
// Last modified:	06/17/2015 (Version 1.0)
//----------------------------------------------------------------------
// Copyright (c) 2015 University of Maryland and David Mount.  All
// Rights Reserved.
// 
// This software and related documentation is part of the Approximate
// Least-Trimmed Squares (ALTS) software.  This software is provided
// under the provisions of the GNU Public License (GPL). See the file
// ReadMe.txt for further information.
// 
// The University of Maryland (U.M.) and the authors make no
// representations about the suitability or fitness of this software for
// any purpose.  It is provided "as is" without express or implied
// warranty.
//----------------------------------------------------------------------
// History:
//	Revision 1.0  06/17/2015
//		Initial release
//----------------------------------------------------------------------

#ifndef ALTS_NUMERIC
#define ALTS_NUMERIC

#include "ALTS.h"						// ALTS definitions

//----------------------------------------------------------------------
//	Entry points
//----------------------------------------------------------------------

namespace alts{

	bool olsFit(						// ordinary least squares fit
		const PointSet&	pts,			// the points
		Plane&			b);				// plane of fit (returned)

	bool fitSlab(						// fit slab to points
		const PointSet&		pts,		// the points
		std::vector<bool>	onTop,		// which points are on top
		Plane&				bTop,		// slab's top plane (modified)
		Plane&				bBot);		// slab's bottom plane (modified)

	LTSResult improveLTSfit(			// locally improve an existing fit
		const PointSet&	pts,			// the points
		int				h,				// trimming parameter
		const Plane&	b);				// initial fitting plane

	Scalar getLTSvariance(				// computes LTS variance of a plane
		const PointSet&	pts,			// the points
		int				h,				// trimming parameter
		const Plane&	b);				// initial fitting plane

	LTSResult slabLTS(
		const PointSet&		pts,		// the point set
		const MSubsetEnum&	slabIdxSet,	// the points defining the slab
		int					h,			// trimming parameter
		const Plane&		bTop,		// top of slab
		const Plane&		bBot);		// bottom of slab
}

#endif
